@@ -136,7 +136,13 @@ class UnifiedAgentRegistry:
 
         # Discovery configuration
         self.file_extensions = {".md", ".json", ".yaml", ".yml"}
-        self.ignore_patterns = {"__pycache__", ".git", "node_modules", ".pytest_cache"}
+        self.ignore_patterns = {
+            "__pycache__",
+            ".git",
+            "node_modules",
+            ".pytest_cache",
+            "backup",
+        }
 
         # Statistics
         self.discovery_stats = {
@@ -166,15 +172,15 @@ class UnifiedAgentRegistry:
         if user_path.exists():
             self.discovery_paths.append(user_path)
 
-        # System-level agents
+        # System-level agents (includes templates as a subdirectory)
         system_path = self.path_manager.get_system_agents_dir()
         if system_path.exists():
             self.discovery_paths.append(system_path)
 
-        # Templates directory
-        templates_path = self.path_manager.get_templates_dir()
-        if templates_path.exists():
-            self.discovery_paths.append(templates_path)
+        # NOTE: Templates directory is NOT added separately because:
+        # - templates_path = system_path / "templates"
+        # - The rglob("*") in _discover_path will already find templates
+        # - Adding it separately causes duplicate discovery
 
         logger.debug(
             f"Discovery paths configured: {[str(p) for p in self.discovery_paths]}"
@@ -256,7 +262,10 @@ class UnifiedAgentRegistry:
             try:
                 metadata = self._create_agent_metadata(file_path, agent_name, tier)
                 if metadata:
-                    self.registry[agent_name] = metadata
+                    # Store all discovered agents temporarily for tier precedence
+                    # Use a unique key that includes tier to prevent overwrites
+                    registry_key = f"{agent_name}_{tier.value}"
+                    self.registry[registry_key] = metadata
                     self.discovered_files.add(file_path)
                     logger.debug(
                         f"Discovered agent: {agent_name} ({tier.value}) at {file_path}"
@@ -269,9 +278,29 @@ class UnifiedAgentRegistry:
         # Remove extension and use filename as agent name
         name = file_path.stem
 
-        # Skip certain files
-        skip_files = {"README", "INSTRUCTIONS", "template", "example"}
-        if name.upper() in skip_files:
+        # Skip certain files and non-agent templates
+        skip_files = {
+            "README",
+            "INSTRUCTIONS",
+            "template",
+            "example",
+            "base_agent",
+            "base_agent_template",
+            "agent_template",
+            "agent_schema",
+            "base_pm",
+            "workflow",
+            "output_style",
+            "memory",
+            "optimization_report",
+            "vercel_ops_instructions",
+            "agent-template",
+            "agent-schema",  # Also handle hyphenated versions
+        }
+        # Case-insensitive comparison
+        if name.replace("-", "_").upper() in {
+            s.replace("-", "_").upper() for s in skip_files
+        }:
             return None
 
         # Normalize name
@@ -391,8 +420,8 @@ class UnifiedAgentRegistry:
             for _i, line in enumerate(lines[1:], 1):
                 if line.strip() == "---":
                     break
-                if line.startswith("description:"):
-                    return line.split(":", 1)[1].strip().strip("\"'")
+                if line.strip().startswith("description:"):
+                    return line.strip().split(":", 1)[1].strip().strip("\"'")
 
         # Look for first paragraph
         for line in lines:
@@ -424,12 +453,14 @@ class UnifiedAgentRegistry:
 
     def _apply_tier_precedence(self) -> None:
         """Apply tier precedence rules to resolve conflicts."""
-        # Group agents by name
+        # Group agents by their actual name (without tier suffix)
         agent_groups = {}
-        for name, metadata in self.registry.items():
-            if name not in agent_groups:
-                agent_groups[name] = []
-            agent_groups[name].append(metadata)
+        for _registry_key, metadata in self.registry.items():
+            # Extract the actual agent name (registry_key is "name_tier")
+            agent_name = metadata.name  # Use the actual name from metadata
+            if agent_name not in agent_groups:
+                agent_groups[agent_name] = []
+            agent_groups[agent_name].append(metadata)
 
         # Resolve conflicts using tier precedence
         resolved_registry = {}
