@@ -195,6 +195,9 @@ class SocketIOServerCore:
             # Setup HTTP API endpoints for receiving events from hook handlers
             self._setup_http_api()
 
+            # Setup simple directory API
+            self._setup_directory_api()
+
             # Find and serve static files
             self._setup_static_files()
 
@@ -390,6 +393,84 @@ class SocketIOServerCore:
         self.app.router.add_post("/api/events", api_events_handler)
         self.logger.info("✅ HTTP API endpoint registered at /api/events")
 
+        # Add file reading endpoint for source viewer
+        async def file_read_handler(request):
+            """Handle GET /api/file/read for reading source files."""
+            import os
+
+            file_path = request.query.get("path", "")
+
+            if not file_path:
+                return web.json_response({"error": "No path provided"}, status=400)
+
+            abs_path = os.path.abspath(os.path.expanduser(file_path))
+
+            # Security check - ensure file is within the project
+            try:
+                project_root = os.getcwd()
+                if not abs_path.startswith(project_root):
+                    return web.json_response({"error": "Access denied"}, status=403)
+            except Exception:
+                pass
+
+            if not os.path.exists(abs_path):
+                return web.json_response({"error": "File not found"}, status=404)
+
+            if not os.path.isfile(abs_path):
+                return web.json_response({"error": "Not a file"}, status=400)
+
+            try:
+                # Read file with appropriate encoding
+                encodings = ["utf-8", "latin-1", "cp1252"]
+                content = None
+
+                for encoding in encodings:
+                    try:
+                        with open(abs_path, encoding=encoding) as f:
+                            content = f.read()
+                        break
+                    except UnicodeDecodeError:
+                        continue
+
+                if content is None:
+                    return web.json_response(
+                        {"error": "Could not decode file"}, status=400
+                    )
+
+                return web.json_response(
+                    {
+                        "path": abs_path,
+                        "name": os.path.basename(abs_path),
+                        "content": content,
+                        "lines": len(content.splitlines()),
+                        "size": os.path.getsize(abs_path),
+                    }
+                )
+
+            except PermissionError:
+                return web.json_response({"error": "Permission denied"}, status=403)
+            except Exception as e:
+                return web.json_response({"error": str(e)}, status=500)
+
+        self.app.router.add_get("/api/file/read", file_read_handler)
+        self.logger.info("✅ File reading API registered at /api/file/read")
+
+    def _setup_directory_api(self):
+        """Setup simple directory listing API.
+
+        WHY: Provides a dead-simple way to list directory contents via HTTP GET
+        without complex WebSocket interactions.
+        """
+        try:
+            from claude_mpm.dashboard.api.simple_directory import register_routes
+
+            register_routes(self.app)
+            self.logger.info(
+                "✅ Simple directory API registered at /api/directory/list"
+            )
+        except Exception as e:
+            self.logger.error(f"Failed to setup directory API: {e}")
+
     def _setup_static_files(self):
         """Setup static file serving for the dashboard."""
         try:
@@ -440,6 +521,26 @@ class SocketIOServerCore:
 
                 self.app.router.add_get("/dashboard", dashboard_handler)
 
+                # Serve simple code view template at /code-simple
+                async def code_simple_handler(request):
+                    code_simple_template = (
+                        self.dashboard_path.parent / "templates" / "code_simple.html"
+                    )
+                    if code_simple_template.exists():
+                        self.logger.debug(
+                            f"Serving code simple template from: {code_simple_template}"
+                        )
+                        return web.FileResponse(code_simple_template)
+                    # Return error if template doesn't exist
+                    self.logger.warning(
+                        f"Code simple template not found at: {code_simple_template}"
+                    )
+                    return web.Response(
+                        text="Simple code view not available", status=404
+                    )
+
+                self.app.router.add_get("/code-simple", code_simple_handler)
+
                 # Serve version.json from dashboard directory
                 async def version_handler(request):
                     version_file = self.dashboard_path / "version.json"
